
/*----------------------------------------------------
Author  : Mark Harvey
Created : 11.01.2016
Version : 1.0

Testbench top level for adder.
Demonstrates use of clocking blocks inside interfaces.

----------------------------------------------------*/

`timescale 1ps/1ps
`include "axis_if.vh"

module tb_adder();

 logic         aclk     = 0;
 logic         aresetn;

 
 /*----------------------------------------------------
   Drive system clock
  ----------------------------------------------------*/ 
   initial begin
    aclk = 0;
    forever #5ns aclk <= ~aclk;
   end


    
  /*----------------------------------------------------
    Instantiate Interfaces
  ----------------------------------------------------*/
  
   // test driver to UUT AXIS connection
   axis if_driver  (.aclk    (aclk) );  
  
   // UUT to test receiver AXIS connection
   axis if_receiver  (.aclk  (aclk) );
  
  

  /*----------------------------------------------------
    Instantiate test driver
  ----------------------------------------------------*/
 
  test_driver U0 (
    .AXIS_MST (if_driver),
    .ARESETN  (aresetn  )
  );
  


  /*----------------------------------------------------
    Instantiate test receiver
  ----------------------------------------------------*/

  test_receiver U1 (
    .AXIS_SLV (if_receiver)
  );

   


  /*----------------------------------------------------
    Instantiate UUT
  ----------------------------------------------------*/

  adder UUT (
    .ACLK     (aclk        ),
    .ARESETN  (aresetn     ),
    .AXIS_SLV (if_driver   ),
    .AXIS_MST (if_receiver )
    );



endmodule : tb_adder
/*----------------------------------------------------
 End of file: tb_adder.sv
----------------------------------------------------*/